@@ -33,7 +33,6 @@ is_bool_like = validate_type_and_token(is_bool, BoolToken)
 # These plug into the pykwalify extension function API
 def validator_like(validate, description):
     def validator(value, rule_obj, path):
-        # pylint: disable=unused-argument
         if validate(value):
             return True
         else:
@@ -62,7 +61,7 @@ def _validate_one_extension(input_value) -> None:
 
     try:
         import_ext_function(input_value["function"])
-    except Exception as e:  # pylint: disable=broad-except
+    except Exception as e:
         raise BadSchemaError("Couldn't load {}".format(input_value["function"])) from e
 
     extra_args = input_value.get("extra_args")
@@ -98,8 +97,6 @@ def validate_extensions(value, rule_obj, path) -> bool:
         BadSchemaError: Something in the validation function spec was wrong
     """
 
-    # pylint: disable=unused-argument
-
     if isinstance(value, list):
         for vf in value:
             _validate_one_extension(vf)
@@ -110,7 +107,6 @@ def validate_extensions(value, rule_obj, path) -> bool:
 
 
 def validate_status_code_is_int_or_list_of_ints(value, rule_obj, path) -> bool:
-    # pylint: disable=unused-argument
     err_msg = "status_code has to be an integer or a list of integers (got {})".format(
         value
     )
@@ -126,7 +122,6 @@ def validate_status_code_is_int_or_list_of_ints(value, rule_obj, path) -> bool:
 
 
 def check_usefixtures(value, rule_obj, path) -> bool:
-    # pylint: disable=unused-argument
     err_msg = "'usefixtures' has to be a list with at least one item"
 
     if not isinstance(value, (list, tuple)):
@@ -140,7 +135,6 @@ def check_usefixtures(value, rule_obj, path) -> bool:
 
 def verify_oneof_id_name(value, rule_obj, path) -> bool:
     """Checks that if 'name' is not present, 'id' is"""
-    # pylint: disable=unused-argument
 
     name = value.get("name")
     if not name:
@@ -154,8 +148,6 @@ def verify_oneof_id_name(value, rule_obj, path) -> bool:
 
 
 def check_parametrize_marks(value, rule_obj, path) -> bool:
-    # pylint: disable=unused-argument
-
     key_or_keys = value["key"]
     vals = value["vals"]
 
@@ -228,7 +220,6 @@ def validate_data_key(value, rule_obj, path) -> bool:
     We could handle lists of tuples, but it seems entirely pointless to maintain
     compatibility for something which is more verbose and does the same thing
     """
-    # pylint: disable=unused-argument
 
     if isinstance(value, dict):
         # Fine
@@ -265,8 +256,6 @@ def validate_request_json(value, rule_obj, path) -> bool:
     just because it seems like you can't match a dict OR a list in pykwalify
     """
 
-    # pylint: disable=unused-argument
-
     def nested_values(d):
         if isinstance(d, dict):
             for v in d.values():
@@ -306,7 +295,6 @@ def validate_json_with_ext(value, rule_obj, path) -> bool:
 
 def check_strict_key(value, rule_obj, path) -> bool:
     """Make sure the 'strict' key is either a bool or a list"""
-    # pylint: disable=unused-argument
 
     if not isinstance(value, list) and not is_bool_like(value):
         raise BadSchemaError("'strict' has to be either a boolean or a list")
@@ -324,7 +312,6 @@ def check_strict_key(value, rule_obj, path) -> bool:
 
 def validate_timeout_tuple_or_float(value, rule_obj, path) -> bool:
     """Make sure timeout is a float/int or a tuple of floats/ints"""
-    # pylint: disable=unused-argument
 
     err_msg = "'timeout' must be either a float/int or a 2-tuple of floats/ints - got '{}' (type {})".format(
         value, type(value)
@@ -349,7 +336,6 @@ def validate_timeout_tuple_or_float(value, rule_obj, path) -> bool:
 
 def validate_verify_bool_or_str(value: Union[bool, str], rule_obj, path) -> bool:
     """Make sure the 'verify' key is either a bool or a str"""
-    # pylint: disable=unused-argument
 
     if not isinstance(value, (bool, str)) and not is_bool_like(value):
         raise BadSchemaError(
@@ -361,7 +347,6 @@ def validate_verify_bool_or_str(value: Union[bool, str], rule_obj, path) -> bool
 
 def validate_cert_tuple_or_str(value, rule_obj, path) -> bool:
     """Make sure the 'cert' key is either a str or tuple"""
-    # pylint: disable=unused-argument
 
     err_msg = (
         "The 'cert' key must be the path to a single file (containing the private key and the certificate) "
@@ -382,7 +367,6 @@ def validate_cert_tuple_or_str(value, rule_obj, path) -> bool:
 
 def validate_file_spec(value, rule_obj, path) -> bool:
     """Validate file upload arguments"""
-    # pylint: disable=unused-argument
 
     if not isinstance(value, dict):
         raise BadSchemaError(
@@ -428,7 +412,6 @@ def validate_file_spec(value, rule_obj, path) -> bool:
 
 def raise_body_error(value, rule_obj, path):
     """Raise an error about the deprecated 'body' key"""
-    # pylint: disable=unused-argument
 
     msg = "The 'body' key has been replaced with 'json' in 1.0 to make it more in line with other blocks. see https://github.com/taverntesting/tavern/issues/495 for details."
     raise BadSchemaError(msg)
@@ -448,7 +431,6 @@ def retry_variable(value: int, rule_obj, path) -> bool:
 
 def validate_http_method(value: str, rule_obj, path) -> bool:
     """Check http method"""
-    # pylint: disable=unused-argument
 
     if not isinstance(value, str):
         raise BadSchemaError("HTTP method should be a string")
