@@ -34,31 +34,31 @@ from tavern._core.stage_lines import (
 logger = logging.getLogger(__name__)
 
 
-def is_str_or_bytes_or_token(checker, instance):  # pylint: disable=unused-argument
+def is_str_or_bytes_or_token(checker, instance):
     return Draft7Validator.TYPE_CHECKER.is_type(instance, "string") or isinstance(
         instance, (bytes, RawStrToken, AnythingSentinel)
     )
 
 
-def is_number_or_token(checker, instance):  # pylint: disable=unused-argument
+def is_number_or_token(checker, instance):
     return Draft7Validator.TYPE_CHECKER.is_type(instance, "number") or isinstance(
         instance, (IntToken, FloatToken, AnythingSentinel)
     )
 
 
-def is_integer_or_token(checker, instance):  # pylint: disable=unused-argument
+def is_integer_or_token(checker, instance):
     return Draft7Validator.TYPE_CHECKER.is_type(instance, "integer") or isinstance(
         instance, (IntToken, AnythingSentinel)
     )
 
 
-def is_boolean_or_token(checker, instance):  # pylint: disable=unused-argument
+def is_boolean_or_token(checker, instance):
     return Draft7Validator.TYPE_CHECKER.is_type(instance, "boolean") or isinstance(
         instance, (BoolToken, AnythingSentinel)
     )
 
 
-def is_object_or_sentinel(checker, instance):  # pylint: disable=unused-argument
+def is_object_or_sentinel(checker, instance):
     return (
         Draft7Validator.TYPE_CHECKER.is_type(instance, "object")
         or isinstance(instance, (TypeSentinel, TypeConvertToken))
@@ -66,9 +66,7 @@ def is_object_or_sentinel(checker, instance):  # pylint: disable=unused-argument
     )
 
 
-def oneOf(  # noqa
-    validator, oneOf, instance, schema  # noqa
-):  # pylint: disable=redefined-outer-name,unused-argument
+def oneOf(validator, oneOf, instance, schema):
     """Patched version of 'oneof' that does not complain if something is matched by multiple branches"""
     subschemas = enumerate(oneOf)
     all_errors = []
@@ -115,8 +113,6 @@ def verify_jsonschema(to_verify, schema) -> None:
         BadSchemaError: Schema did not match
     """
 
-    # pylint: disable=too-many-locals
-
     validator = CustomValidator(schema)
 
     try:
