@@ -15,7 +15,7 @@ def sdkofsok(str_fixture):
 def bluerhug(request):
     # This doesn't really do anything at the moment. In future it might yield
     # the result or something, but it's a bit difficult to do at the moment.
-    response = yield "hello"
+    yield "hello"
 
 
 @pytest.fixture(scope="session", autouse=True)
